import java.awt.*;
import java.awt.event.*;
import java.util.LinkedList;
import javax.swing.*;
import java.io.FileReader;
import java.io.BufferedReader;
import java.io.StreamTokenizer;
import H.*;

class Grid extends Drawable
{
    protected int m_nrows, m_ncols;
    protected Color[][] m_colors;
    protected int count = 0;
    protected int m_xorig,     // upper left x for drawing
                  m_yorig,     // upper left y for drawing
                  m_maxdim;    // the length of a square side
    
    public Grid(int nrows, int ncols)
    {
        m_nrows = nrows;
        m_ncols = ncols;
        m_colors = new Color[nrows][ncols];
        initializeColors(Color.white);
    }
    
    protected void initializeColors(Color c)
    {
        for (int row=0 ; row<m_nrows ; ++row)
        {
            for (int col=0 ; col<m_ncols ; ++col)
            {  
                /*
                 * this was the checkerboard test pattern
                 */
                //if ( (row+col)%2 == 0) m_colors[row][col] = c;
                //else m_colors[row][col] = Color.black;
                
                /*
                 * the more vanilla variety
                 */
                m_colors[row][col] = c;
            }
        }
    }
    
    public void nextStep()
    {
        ++count;
        H.pl("in nextStep: count is " + count);
        if (count%2 == 0)
            initializeColors(Color.green);
        else
            initializeColors(Color.red);
    }
    
    public void handleResizeEvent()
    {
        // figure the minimum dimension possible, i.e.,
        // the largest _square_ cell that will fit
        m_maxdim = height/m_nrows;
        if (m_maxdim > width/m_ncols)
            m_maxdim = width/m_ncols;
            
        int margin;
        
        // start y at 1/2 of the vertical margin
        margin = (height - m_nrows*m_maxdim)/2;
        if (margin<0) margin = 0;
        m_yorig = margin;
        
        // start x at 1/2 of the horizontal margin
        margin = (width - m_ncols*m_maxdim)/2;
        if (margin<0) margin = 0;
        m_xorig = margin;        
    }
    
    public void draw()
    {
        //H.pl("drawing");
        
        // check if the squares' sides are at least 1...
        if (m_maxdim < 1)
        {
            if (width > m_ncols && height > m_nrows)
                Drawable.resizeHandler(); // it needs resizing
            else {            
                H.pl("WARNING: the window is too small to fit a grid object");
                H.pl("  with " + m_ncols + " columns and " + m_nrows + " rows.");
                H.pl("  The panel size is " + width + " pixels wide and " + 
                     height + " pixels high.");
                H.pl("  Nothing will be drawn for this object.\n");
                Drawable.resizeHandler(); // in case it's been resized
                return;
            }
        }
        
        // x and y will march through screen (pixel) coordinates
        int x = m_xorig;
        int y = m_yorig;
        
        for (int row=0 ; row<m_nrows ; ++row)   // for each row
        {
            for (int col=0 ; col<m_ncols ; ++col)  // for each column
            {       
                g.setColor(m_colors[row][col]);     // set the color
                g.fillRect(x,y,m_maxdim,m_maxdim);  // draw!
                x += m_maxdim;  // move one square over to the right
            }
            
            y += m_maxdim;    // move down one row
            x = m_xorig;      // move back to the left side
            
        }
           
    }
}
	